@@ -17,6 +17,9 @@
 #ifdef HARP_EXPAT_NAME_MANGLE
 
 #define _INTERNAL_trim_to_complete_utf8_characters harp_INTERNAL_trim_to_complete_utf8_characters
+#define testingAccountingGetCountBytesDirect harp_testingAccountingGetCountBytesDirect
+#define testingAccountingGetCountBytesIndirect harp_testingAccountingGetCountBytesIndirect
+#define unsignedCharToPrintable harp_unsignedCharToPrintable
 #define XML_DefaultCurrent harp_XML_DefaultCurrent
 #define XML_ErrorString harp_XML_ErrorString
 #define XML_ExpatVersion harp_XML_ExpatVersion
@@ -48,6 +51,8 @@
 #define XML_ResumeParser harp_XML_ResumeParser
 #define XML_SetAttlistDeclHandler harp_XML_SetAttlistDeclHandler
 #define XML_SetBase harp_XML_SetBase
+#define XML_SetBillionLaughsAttackProtectionActivationThreshold harp_XML_SetBillionLaughsAttackProtectionActivationThreshold
+#define XML_SetBillionLaughsAttackProtectionMaximumAmplification harp_XML_SetBillionLaughsAttackProtectionMaximumAmplification
 #define XML_SetCdataSectionHandler harp_XML_SetCdataSectionHandler
 #define XML_SetCharacterDataHandler harp_XML_SetCharacterDataHandler
 #define XML_SetCommentHandler harp_XML_SetCommentHandler
