@@ -1206,6 +1206,12 @@ def import_product(filename, operations="", options="", reduce_operations="", po
     will be called on each individual matching file. All imported products will then
     be appended into a single merged product and that merged product will be returned.
 
+    If the filename argument is a .pth file, then the products referenced in the .pth
+    file will be treated as a HARP Dataset and its merged content will be returned.
+    Note that the `source_product` attribute of products in a HARP Dataset needs to be
+    unique; if a dataset contains multiple products with the same `source_product` value
+    then only the last product in the list will be kept.
+
     Arguments:
     filename -- Filename, file pattern, .pth file, or list of filenames/patterns/.pths of
                 the product(s) to import
@@ -1451,8 +1457,10 @@ def _get_time_length(product):
 def _extend_variable_for_dim(variable, dim_index, new_length):
     shape = list(variable.data.shape)
     shape[dim_index] = new_length - shape[dim_index]
-    filler = numpy.empty(shape, dtype=variable.data.dtype)
-    filler[:] = numpy.nan
+    if variable.data.dtype.kind == 'f':
+        filler = numpy.full(shape, numpy.nan, dtype=variable.data.dtype)
+    else:
+        filler = numpy.zeros(shape, dtype=variable.data.dtype)
     variable.data = numpy.concatenate([variable.data, filler], axis=dim_index)
 
 
